(self.webpackJsonp=self.webpackJsonp||[]).push([[38],{813:function(e,r,n){"use strict";n.r(r),n.d(r,"codeMirror",(function(){return c})),n.d(r,"codeMirrorCss",(function(){return i}));var s=n(504),o=n.n(s),t=n(712),a=(n(713),n(714),n(13));o.a.commands.save=e=>{Object(a.a)(e.getWrapperElement(),"editor-save")};const c=o.a,i=t.a}}]);
//# sourceMappingURL=chunk.55117897e20d90da64e2.js.map