(self.webpackJsonp=self.webpackJsonp||[]).push([[40],{819:function(e,r,n){"use strict";n.r(r),n.d(r,"codeMirror",(function(){return c})),n.d(r,"codeMirrorCss",(function(){return i}));var a=n(442),o=n.n(a),s=n(718),t=(n(719),n(720),n(13));o.a.commands.save=function(e){Object(t.a)(e.getWrapperElement(),"editor-save")};var c=o.a,i=s.a}}]);
//# sourceMappingURL=chunk.7b9b08361a84305ef130.js.map